@@ -550,17 +550,3 @@ impl FromStr for GlifVersion {
         }
     }
 }
-
-impl FromStr for PointType {
-    type Err = ErrorKind;
-    fn from_str(s: &str) -> Result<Self, Self::Err> {
-        match s {
-            "move" => Ok(PointType::Move),
-            "line" => Ok(PointType::Line),
-            "offcurve" => Ok(PointType::OffCurve),
-            "curve" => Ok(PointType::Curve),
-            "qcurve" => Ok(PointType::QCurve),
-            _other => Err(ErrorKind::UnknownPointType),
-        }
-    }
-}
