@@ -2,6 +2,7 @@ use super::parse::parse_glyph;
 use super::*;
 use crate::write::QuoteChar;
 use std::path::PathBuf;
+use std::str::FromStr;
 
 #[test]
 #[allow(clippy::float_cmp)]
@@ -26,6 +27,17 @@ fn serialize_empty_glyph() {
     );
 }
 
+#[test]
+fn serialize_empty_glyph_explicit_line_ending_check() {
+    let glyph = Glyph::new_named("a");
+    let glif = glyph.encode_xml().unwrap();
+    let glif = std::str::from_utf8(&glif).unwrap();
+    assert_eq!(
+        glif,
+        "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<glyph name=\"a\" format=\"2\">\n</glyph>\n"
+    );
+}
+
 #[test]
 fn serialize_full_glyph() {
     let source = include_str!("../../testdata/sample_period_normalized.glif");
@@ -572,3 +584,27 @@ fn empty_contours() {
     assert_eq!(test2.components, vec![]);
     assert_eq!(test2.contours, vec![]);
 }
+
+#[test]
+fn pointtype_display_trait() {
+    assert_eq!(format!("{}", PointType::Move), "move");
+    assert_eq!(format!("{}", PointType::Line), "line");
+    assert_eq!(format!("{}", PointType::OffCurve), "offcurve");
+    assert_eq!(format!("{}", PointType::Curve), "curve");
+    assert_eq!(format!("{}", PointType::QCurve), "qcurve");
+}
+
+#[test]
+fn pointtype_from_str_trait() {
+    assert!(PointType::from_str("move").unwrap() == PointType::Move);
+    assert!(PointType::from_str("line").unwrap() == PointType::Line);
+    assert!(PointType::from_str("offcurve").unwrap() == PointType::OffCurve);
+    assert!(PointType::from_str("curve").unwrap() == PointType::Curve);
+    assert!(PointType::from_str("qcurve").unwrap() == PointType::QCurve);
+}
+
+#[test]
+#[should_panic(expected = "UnknownPointType")]
+fn pointtype_from_str_unknown_type() {
+    PointType::from_str("bogus").unwrap();
+}
